OC.L10N.register(
    "files_texteditor",
    {
    "This file is too big to be opened. Please download the file instead." : "Ce fichier est trop volumineux pour être ouvert. Veuillez plutôt le télécharger.",
    "Cannot read the file." : "Impossible de lire le fichier.",
    "Invalid file path supplied." : "Chemin de fichier fourni non valide.",
    "The file is locked." : "Le fichier est verrouillé.",
    "An internal server error occurred." : "Une erreur interne au serveur est survenue.",
    "Cannot save file as it has been modified since opening" : "Impossible de sauvegarder le fichier, il a été modifié entre temps",
    "Insufficient permissions" : "Permissions insuffisantes",
    "File path not supplied" : "Chemin du fichier non fourni",
    "File mtime not supplied" : "mtime du fichier non fourni",
    "saving..." : "enregistrement...",
    "saved!" : "enregistré!",
    "failed!" : "échec!",
    "Saved" : "Sauvegardé",
    "There was a problem saving your changes. Click to resume editing." : "Un problème est survenu lors de la sauvegarde de vos modifications. Cliquez pour continuer l'édition.",
    "An error occurred!" : "Une erreur est survenue !",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt"
},
"nplurals=2; plural=(n > 1);");
